pub struct BrowserBridgeAuthorization { /* private fields */ }Expand description
Non-forgeable current-generation permission for an exact browser origin.
Implementations
Sourceimpl BrowserBridgeAuthorization
impl BrowserBridgeAuthorization
Sourcepub const fn runtime_session(&self) -> [u8; 16]
pub const fn runtime_session(&self) -> [u8; 16]
Runtime session that issued the authorization.
Sourcepub const fn runtime_generation(&self) -> u64
pub const fn runtime_generation(&self) -> u64
Runtime generation that issued the authorization.
Sourcepub const fn policy_generation(&self) -> u64
pub const fn policy_generation(&self) -> u64
Policy generation that issued the authorization.
Sourcepub const fn event_sequence(&self) -> u64
pub const fn event_sequence(&self) -> u64
Authorization event sequence.
Sourcepub const fn valid_from(&self) -> u64
pub const fn valid_from(&self) -> u64
First chain-currency time at which this grant may be consumed.
Sourcepub const fn valid_until(&self) -> u64
pub const fn valid_until(&self) -> u64
Last chain-currency time at which this grant may be consumed.